texlive[45853] trunk: crossrefware (19nov17)

commits+karl at tug.org commits+karl at tug.org
Sun Nov 19 23:17:35 CET 2017


Revision: 45853
          http://tug.org/svn/texlive?view=revision&revision=45853
Author:   karl
Date:     2017-11-19 23:17:35 +0100 (Sun, 19 Nov 2017)
Log Message:
-----------
crossrefware (19nov17)

Modified Paths:
--------------
    trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bbl2bib.pl
    trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibdoiadd.pl
    trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibmradd.pl
    trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibzbladd.pl
    trunk/Build/source/texk/texlive/linked_scripts/crossrefware/ltx2crossrefxml.pl
    trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
    trunk/Master/texmf-dist/doc/man/man1/bbl2bib.1
    trunk/Master/texmf-dist/doc/man/man1/bbl2bib.man1.pdf
    trunk/Master/texmf-dist/doc/man/man1/bibdoiadd.1
    trunk/Master/texmf-dist/doc/man/man1/bibdoiadd.man1.pdf
    trunk/Master/texmf-dist/doc/man/man1/bibmradd.1
    trunk/Master/texmf-dist/doc/man/man1/bibmradd.man1.pdf
    trunk/Master/texmf-dist/doc/man/man1/bibzbladd.1
    trunk/Master/texmf-dist/doc/man/man1/bibzbladd.man1.pdf
    trunk/Master/texmf-dist/doc/man/man1/ltx2crossrefxml.1
    trunk/Master/texmf-dist/doc/man/man1/ltx2crossrefxml.man1.pdf
    trunk/Master/texmf-dist/doc/support/crossrefware/Makefile
    trunk/Master/texmf-dist/doc/support/crossrefware/README
    trunk/Master/texmf-dist/doc/support/crossrefware/crossrefware.pdf
    trunk/Master/texmf-dist/scripts/crossrefware/bbl2bib.pl
    trunk/Master/texmf-dist/scripts/crossrefware/bibdoiadd.pl
    trunk/Master/texmf-dist/scripts/crossrefware/bibmradd.pl
    trunk/Master/texmf-dist/scripts/crossrefware/bibzbladd.pl
    trunk/Master/texmf-dist/scripts/crossrefware/ltx2crossrefxml.pl

Added Paths:
-----------
    trunk/Master/texmf-dist/doc/support/crossrefware/citations.bib

Modified: trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bbl2bib.pl
===================================================================
--- trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bbl2bib.pl	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bbl2bib.pl	2017-11-19 22:17:35 UTC (rev 45853)
@@ -8,13 +8,15 @@
 
 =head1 SYNOPSIS
 
-bbl2bib.pl [B<-o> I<output>] I<file>
+bbl2bib.pl [-d] [B<-o> I<output>] I<file>
 
 =head1 OPTIONS
 
 =over 4
 
+=item [-d]
 
+Send debugging output to stdout
 
 =item B<-o> I<output>
 
@@ -98,10 +100,13 @@
 use Getopt::Std;
 use URI::Escape;
 use LWP::Simple;
+# Sometimes AMS forgets to update certificates
+$ENV{PERL_LWP_SSL_VERIFY_HOSTNAME}=0;
 
+
 my $USAGE="USAGE: $0 [-o output] file\n";
 my $VERSION = <<END;
-bbl2bib v2.1a
+bbl2bib v2.2
 This is free software.  You may redistribute copies of it under the
 terms of the GNU General Public License
 http://www.gnu.org/licenses/gpl.html.  There is NO WARRANTY, to the
@@ -109,7 +114,7 @@
 $USAGE
 END
 our %opts;
-getopts('c:o:s:hV',\%opts) or die $USAGE;
+getopts('do:hV',\%opts) or die $USAGE;
 
 if ($opts{h} || $opts{V}){
     print $VERSION;
@@ -130,6 +135,10 @@
     $outputfile = $opts{o};
 }
 
+my $debug=0;
+if ($opts{d}) {
+    $debug=1;
+}
 
 
 my $input= IO::File->new($inputfile) or 
@@ -168,7 +177,15 @@
     my $bibitem = shift;
     my $key = $bibitem->{key};
     my $text=$bibitem->{text};
+
+    if ($debug) {
+	print STDOUT "DEBUG: Processing item $key\n";
+    }
+    
     if (!length($text) || $text =~ /^\s+$/s) {
+	if ($debug) {
+	    print STDOUT "DEBUG: No text found\n";
+	}
 	return;
     }
 
@@ -180,21 +197,33 @@
 
     # Arxiv entry?
     if ($text =~ s/\\arxiv\{([^\}]+)\}\.?//) {
+	if ($debug) {
+	    print STDOUT "DEBUG: Found arXiv number $1\n";
+	}
 	$bibitem->{arxiv}=$1;
     }
 
     # Mr number exists?
     if ($text =~ s/\\mr\{([^\}]+)\}\.?//) {
+	if ($debug) {
+	    print STDOUT "DEBUG: Found mr number $1\n";
+	}
 	$bibitem->{mr}=$1;
     }
 
     # zbl  number exists?
     if ($text =~ s/\\zbl\{([^\}]+)\}\.?//) {
+	if ($debug) {
+	    print STDOUT "DEBUG: Found zbl number $1\n";
+	}
 	$bibitem->{zbl}=$1;
     }
 
     # doi  number exists?
     if ($text =~ s/\\doi\{([^\}]+)\}\.?//) {
+	if ($debug) {
+	    print STDOUT "DEBUG: Found doi $1\n";
+	}
 	$bibitem->{doi}=$1;
     }
 
@@ -208,8 +237,14 @@
     my $bibitem = shift;
     my $mirror = "http://www.ams.org/mathscinet-mref";
     my $string=uri_escape_utf8($bibitem->{text});
+    if ($debug) {
+	print STDOUT "Sending $mirror?ref=$string".'&'."dataType=bibtex\n"
+    }
     my $response = $userAgent->get("$mirror?ref=$string&dataType=bibtex") ->
 	decoded_content();
+    if ($debug) {
+	print STDOUT "DEBUG: Response $response\n";
+    }
     if ($response =~ /<pre>(.*)<\/pre>/s) {
 	my $bib= $1;
 	my $fh = new FileHandle;

Modified: trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibdoiadd.pl
===================================================================
--- trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibdoiadd.pl	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibdoiadd.pl	2017-11-19 22:17:35 UTC (rev 45853)
@@ -104,10 +104,12 @@
 use Getopt::Std;
 use URI::Escape;
 use LWP::Simple;
+# Sometimes AMS forgets to update certificates
+$ENV{PERL_LWP_SSL_VERIFY_HOSTNAME}=0;
 
 my $USAGE="USAGE: $0 [-c config] [-e 1|0] [-f] [-o output] file\n";
 my $VERSION = <<END;
-bibdoiadd v2.1
+bibdoiadd v2.2
 This is free software.  You may redistribute copies of it under the
 terms of the GNU General Public License
 http://www.gnu.org/licenses/gpl.html.  There is NO WARRANTY, to the

Modified: trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibmradd.pl
===================================================================
--- trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibmradd.pl	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibmradd.pl	2017-11-19 22:17:35 UTC (rev 45853)
@@ -75,10 +75,12 @@
 use URI::Escape;
 use LWP::UserAgent;
 $ENV{PERL_LWP_SSL_VERIFY_HOSTNAME}=0;
+# Sometimes AMS forgets to update certificates
+$ENV{PERL_LWP_SSL_VERIFY_HOSTNAME}=0;
 
 my $USAGE="USAGE: $0  [-d] [-e 1|0] [-f] [-o output] file\n";
 my $VERSION = <<END;
-bibmradd v2.1
+bibmradd v2.2
 This is free software.  You may redistribute copies of it under the
 terms of the GNU General Public License
 http://www.gnu.org/licenses/gpl.html.  There is NO WARRANTY, to the

Modified: trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibzbladd.pl
===================================================================
--- trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibzbladd.pl	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Build/source/texk/texlive/linked_scripts/crossrefware/bibzbladd.pl	2017-11-19 22:17:35 UTC (rev 45853)
@@ -78,7 +78,7 @@
 
 my $USAGE="USAGE: $0  [-d] [-e 1|0] [-f] [-o output] file\n";
 my $VERSION = <<END;
-bibzbladd v2.1
+bibzbladd v2.2
 This is free software.  You may redistribute copies of it under the
 terms of the GNU General Public License
 http://www.gnu.org/licenses/gpl.html.  There is NO WARRANTY, to the

Modified: trunk/Build/source/texk/texlive/linked_scripts/crossrefware/ltx2crossrefxml.pl
===================================================================
--- trunk/Build/source/texk/texlive/linked_scripts/crossrefware/ltx2crossrefxml.pl	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Build/source/texk/texlive/linked_scripts/crossrefware/ltx2crossrefxml.pl	2017-11-19 22:17:35 UTC (rev 45853)
@@ -82,7 +82,7 @@
  use File::Spec;
  my $USAGE="USAGE: $0 [-c config] [-o output] file1 file2 ...\n";
 my $VERSION = <<END;
-ltx2crossrefxml v2.0
+ltx2crossrefxml v2.2
 This is free software.  You may redistribute copies of it under the
 terms of the GNU General Public License
 http://www.gnu.org/licenses/gpl.html.  There is NO WARRANTY, to the

Modified: trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
===================================================================
--- trunk/Master/texmf-dist/doc/man/man1/bbl2bib.1	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/doc/man/man1/bbl2bib.1	2017-11-19 22:17:35 UTC (rev 45853)
@@ -1,4 +1,4 @@
-.\" Automatically generated by Pod::Man 2.28 (Pod::Simple 3.28)
+.\" Automatically generated by Pod::Man 2.27 (Pod::Simple 3.28)
 .\"
 .\" Standard preamble:
 .\" ========================================================================
@@ -133,7 +133,7 @@
 .\" ========================================================================
 .\"
 .IX Title "bbl2bib 1"
-.TH bbl2bib 1 "2017-04-23" "" "CROSSREF LIBRARY"
+.TH bbl2bib 1 "2017-11-18" "" "CROSSREF LIBRARY"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l
@@ -142,9 +142,12 @@
 bbl2bib.pl \- convert thebibliography environment to a bib file
 .SH "SYNOPSIS"
 .IX Header "SYNOPSIS"
-bbl2bib.pl [\fB\-o\fR \fIoutput\fR] \fIfile\fR
+bbl2bib.pl [\-d] [\fB\-o\fR \fIoutput\fR] \fIfile\fR
 .SH "OPTIONS"
 .IX Header "OPTIONS"
+.IP "[\-d]" 4
+.IX Item "[-d]"
+Send debugging output to stdout
 .IP "\fB\-o\fR \fIoutput\fR" 4
 .IX Item "-o output"
 Output file.  If this option is not used, the name for the 

Modified: trunk/Master/texmf-dist/doc/man/man1/bbl2bib.man1.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/man/man1/bibdoiadd.1
===================================================================
--- trunk/Master/texmf-dist/doc/man/man1/bibdoiadd.1	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/doc/man/man1/bibdoiadd.1	2017-11-19 22:17:35 UTC (rev 45853)
@@ -1,4 +1,4 @@
-.\" Automatically generated by Pod::Man 2.28 (Pod::Simple 3.28)
+.\" Automatically generated by Pod::Man 2.27 (Pod::Simple 3.28)
 .\"
 .\" Standard preamble:
 .\" ========================================================================
@@ -133,7 +133,7 @@
 .\" ========================================================================
 .\"
 .IX Title "bibdoiadd 1"
-.TH bibdoiadd 1 "2017-04-09" "" "CROSSREF LIBRARY"
+.TH bibdoiadd 1 "2017-11-18" "" "CROSSREF LIBRARY"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l

Modified: trunk/Master/texmf-dist/doc/man/man1/bibdoiadd.man1.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/man/man1/bibmradd.1
===================================================================
--- trunk/Master/texmf-dist/doc/man/man1/bibmradd.1	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/doc/man/man1/bibmradd.1	2017-11-19 22:17:35 UTC (rev 45853)
@@ -1,4 +1,4 @@
-.\" Automatically generated by Pod::Man 2.28 (Pod::Simple 3.28)
+.\" Automatically generated by Pod::Man 2.27 (Pod::Simple 3.28)
 .\"
 .\" Standard preamble:
 .\" ========================================================================
@@ -133,7 +133,7 @@
 .\" ========================================================================
 .\"
 .IX Title "bibmradd 1"
-.TH bibmradd 1 "2017-04-03" "" "CROSSREF LIBRARY"
+.TH bibmradd 1 "2017-11-18" "" "CROSSREF LIBRARY"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l

Modified: trunk/Master/texmf-dist/doc/man/man1/bibmradd.man1.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/man/man1/bibzbladd.1
===================================================================
--- trunk/Master/texmf-dist/doc/man/man1/bibzbladd.1	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/doc/man/man1/bibzbladd.1	2017-11-19 22:17:35 UTC (rev 45853)
@@ -1,4 +1,4 @@
-.\" Automatically generated by Pod::Man 2.28 (Pod::Simple 3.28)
+.\" Automatically generated by Pod::Man 2.27 (Pod::Simple 3.28)
 .\"
 .\" Standard preamble:
 .\" ========================================================================
@@ -133,7 +133,7 @@
 .\" ========================================================================
 .\"
 .IX Title "bibzbladd 1"
-.TH bibzbladd 1 "2017-04-02" "" "CROSSREF LIBRARY"
+.TH bibzbladd 1 "2017-11-18" "" "CROSSREF LIBRARY"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l

Modified: trunk/Master/texmf-dist/doc/man/man1/bibzbladd.man1.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/man/man1/ltx2crossrefxml.1
===================================================================
--- trunk/Master/texmf-dist/doc/man/man1/ltx2crossrefxml.1	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/doc/man/man1/ltx2crossrefxml.1	2017-11-19 22:17:35 UTC (rev 45853)
@@ -1,4 +1,4 @@
-.\" Automatically generated by Pod::Man 2.22 (Pod::Simple 3.07)
+.\" Automatically generated by Pod::Man 2.27 (Pod::Simple 3.28)
 .\"
 .\" Standard preamble:
 .\" ========================================================================
@@ -38,6 +38,8 @@
 .    ds PI \(*p
 .    ds L" ``
 .    ds R" ''
+.    ds C`
+.    ds C'
 'br\}
 .\"
 .\" Escape single quotes in literal strings from groff's Unicode transform.
@@ -48,17 +50,24 @@
 .\" titles (.TH), headers (.SH), subsections (.SS), items (.Ip), and index
 .\" entries marked with X<> in POD.  Of course, you'll have to process the
 .\" output yourself in some meaningful fashion.
-.ie \nF \{\
-.    de IX
-.    tm Index:\\$1\t\\n%\t"\\$2"
+.\"
+.\" Avoid warning from groff about undefined register 'F'.
+.de IX
 ..
-.    nr % 0
-.    rr F
-.\}
-.el \{\
-.    de IX
+.nr rF 0
+.if \n(.g .if rF .nr rF 1
+.if (\n(rF:(\n(.g==0)) \{
+.    if \nF \{
+.        de IX
+.        tm Index:\\$1\t\\n%\t"\\$2"
 ..
+.        if !\nF==2 \{
+.            nr % 0
+.            nr F 2
+.        \}
+.    \}
 .\}
+.rr rF
 .\"
 .\" Accent mark definitions (@(#)ms.acc 1.5 88/02/08 SMI; from UCB 4.2).
 .\" Fear.  Run.  Save yourself.  No user-serviceable parts.
@@ -124,7 +133,7 @@
 .\" ========================================================================
 .\"
 .IX Title "ltx2crossrefxml 1"
-.TH ltx2crossrefxml 1 "2016-02-14" "" "CROSSREF LIBRARY"
+.TH ltx2crossrefxml 1 "2017-11-18" "" "CROSSREF LIBRARY"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l
@@ -176,5 +185,5 @@
 .PP
 This is free software.  You may redistribute copies of it under the
 terms of the \s-1GNU\s0 General Public License
-<http://www.gnu.org/licenses/gpl.html>.  There is \s-1NO\s0 \s-1WARRANTY\s0, to the
+<http://www.gnu.org/licenses/gpl.html>.  There is \s-1NO WARRANTY,\s0 to the
 extent permitted by law.

Modified: trunk/Master/texmf-dist/doc/man/man1/ltx2crossrefxml.man1.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/support/crossrefware/Makefile
===================================================================
--- trunk/Master/texmf-dist/doc/support/crossrefware/Makefile	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/doc/support/crossrefware/Makefile	2017-11-19 22:17:35 UTC (rev 45853)
@@ -5,6 +5,7 @@
 	bibmradd.pl \
 	bbl2bib.pl
 
+PACKAGE = crossrefware
 
 MAN1 = ${SCRIPTS:%.pl=%.1}
 
@@ -40,5 +41,4 @@
 	pod2latex -modify -full -prefile head.ltx -out $@ $+
 
 archive: all clean
-	cd ..; tar -czvf crossrefware.tgz  --exclude 'CVS' \
-	--exclude 'test' --exclude *.bib crossref
+	COPYFILE_DISABLE=1 tar -C .. -czvf ../$(PACKAGE).tgz --exclude '*~' --exclude '*.tgz' --exclude '*.zip'  --exclude CVS --exclude '.git*' $(PACKAGE); mv ../$(PACKAGE).tgz .

Modified: trunk/Master/texmf-dist/doc/support/crossrefware/README
===================================================================
--- trunk/Master/texmf-dist/doc/support/crossrefware/README	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/doc/support/crossrefware/README	2017-11-19 22:17:35 UTC (rev 45853)
@@ -1,5 +1,5 @@
 			 Crossrefware Bundle
-			     version 2.1a
+			     version 2.2
 
 
 Scripts useful for working with Crossref, MathSciNet and Zentralblatt MATH.
@@ -26,6 +26,9 @@
 
 Changes:
 
+	Version 2.2:  We now treat absent CA permissively.
+		      New debug options for bbl2bib
+
         Version 2.1a: Bug in bbl2bib corrected
 
         Version 2.1:  New options to add empty doi and zbl when doi or zbl

Added: trunk/Master/texmf-dist/doc/support/crossrefware/citations.bib
===================================================================
--- trunk/Master/texmf-dist/doc/support/crossrefware/citations.bib	                        (rev 0)
+++ trunk/Master/texmf-dist/doc/support/crossrefware/citations.bib	2017-11-19 22:17:35 UTC (rev 45853)
@@ -0,0 +1,811 @@
+
+ at incollection {amicevelu75,
+    MRKEY = {MR0376534},
+    AUTHOR = {Amice, Yvette and V{\'e}lu, Jacques},
+     TITLE = {Distributions {$p$}-adiques associ\'ees aux s\'eries de
+              {H}ecke},
+ BOOKTITLE = {Journ\'ees {A}rithm\'etiques de {B}ordeaux ({C}onf., {U}niv.
+              {B}ordeaux, {B}ordeaux, 1974)},
+     PAGES = {119--131. Ast\'erisque, Nos. 24-25},
+ PUBLISHER = {Soc. Math. France},
+   ADDRESS = {Paris},
+      YEAR = {1975},
+   MRCLASS = {10D05},
+  MRNUMBER = {0376534 (51 \#12709},
+MRREVIEWER = {O. M. Fomenko},
+}
+
+%%%%
+
+ at article {ashstevens86,
+    MRKEY = {MR860675},
+    AUTHOR = {Ash, Avner and Stevens, Glenn},
+     TITLE = {Modular forms in characteristic {$l$} and special values of
+              their {$L$}-functions},
+   JOURNAL = {Duke Math. J.},
+  FJOURNAL = {Duke Mathematical Journal},
+    VOLUME = {53},
+      YEAR = {1986},
+    NUMBER = {3},
+     PAGES = {849--868},
+      ISSN = {0012-7094},
+     CODEN = {DUMJAO},
+   MRCLASS = {11F75},
+  MRNUMBER = {860675 (88h:11036},
+        URL = {http://dx.doi.org/10.1215/S0012-7094-86-05346-9},
+}
+
+%%%%
+
+
+ at incollection {MR760999,
+    MRKEY = {MR760999},
+    AUTHOR = {Be{\u\i}linson, A. A.},
+     TITLE = {Higher regulators and values of {$L$}-functions},
+ BOOKTITLE = {Current problems in mathematics, {V}ol. 24},
+    SERIES = {Itogi Nauki i Tekhniki},
+     PAGES = {181--238},
+ PUBLISHER = {Akad. Nauk SSSR Vsesoyuz. Inst. Nauchn. i Tekhn. Inform.},
+   ADDRESS = {Moscow},
+      YEAR = {1984},
+   MRCLASS = {11R42 (11G40 11G45 11R70 14C35 18F25 19F27)},
+  MRNUMBER = {760999 (86h:11103},
+MRREVIEWER = {Daniel R. Grayson},
+}
+
+%%%%
+
+
+ at article {bergerlizhu04,
+    MRKEY = {MR2060368},
+    AUTHOR = {Berger, Laurent and Li, Hanfeng and Zhu, Hui June},
+     TITLE = {Construction of some families of 2-dimensional crystalline
+              representations},
+   JOURNAL = {Math. Ann.},
+  FJOURNAL = {Mathematische Annalen},
+    VOLUME = {329},
+      YEAR = {2004},
+    NUMBER = {2},
+     PAGES = {365--377},
+      ISSN = {0025-5831},
+     CODEN = {MAANA},
+   MRCLASS = {11F80 (11F33 11F85 14F30)},
+  MRNUMBER = {2060368 (2005k:11104},
+MRREVIEWER = {Abdellah Mokrane},
+     URL = {http://dx.doi.org/10.1007/s00208-004-0529-y},
+}
+
+%%%%
+
+%%%%
+
+ at inproceedings {besser00,
+    MRKEY = {MR1809626},
+    AUTHOR = {Besser, Amnon},
+     TITLE = {Syntomic regulators and {$p$}-adic integration. {I}. {R}igid
+              syntomic regulators},
+ BOOKTITLE = {Proceedings of the {C}onference on {$p$}-adic {A}spects of the
+              {T}heory of {A}utomorphic {R}epresentations ({J}erusalem,
+              1998)},
+   JOURNAL = {Israel J. Math.},
+  FJOURNAL = {Israel Journal of Mathematics},
+    VOLUME = {120},
+      YEAR = {2000},
+    NUMBER = {part B},
+     PAGES = {291--334},
+      ISSN = {0021-2172},
+     CODEN = {ISJMAP},
+   MRCLASS = {14F43 (11G25 14F30 14G22 19F27)},
+  MRNUMBER = {1809626 (2002c:14035},
+MRREVIEWER = {Takao Yamazaki},
+         URL = {http://dx.doi.org/10.1007/BF02834843},
+}
+
+%%%%
+
+ at incollection {blochkato90,
+    MRKEY = {MR1086888},
+    AUTHOR = {Bloch, Spencer and Kato, Kazuya},
+     TITLE = {{$L$}-functions and {T}amagawa numbers of motives},
+ BOOKTITLE = {The {G}rothendieck {F}estschrift, {V}ol.\ {I}},
+    SERIES = {Progr. Math.},
+    VOLUME = {86},
+     PAGES = {333--400},
+ PUBLISHER = {Birkh\"auser Boston},
+   ADDRESS = {Boston, MA},
+      YEAR = {1990},
+   MRCLASS = {11G40 (11G09 14C35 14F30 14G10)},
+  MRNUMBER = {1086888 (92g:11063},
+MRREVIEWER = {Ehud de Shalit},
+}
+
+%%%%
+
+ at article {colemanedixhoven98,
+    MRKEY = {MR1600034},
+    AUTHOR = {Coleman, Robert F. and Edixhoven, Bas},
+     TITLE = {On the semi-simplicity of the {$U\sb p$}-operator on modular
+              forms},
+   JOURNAL = {Math. Ann.},
+  FJOURNAL = {Mathematische Annalen},
+    VOLUME = {310},
+      YEAR = {1998},
+    NUMBER = {1},
+     PAGES = {119--127},
+      ISSN = {0025-5831},
+   MRCLASS = {11F25 (11F11 11F33 11F85)},
+  MRNUMBER = {1600034 (99b:11043},
+MRREVIEWER = {Alexey A. Panchishkin},
+      URL = {http://dx.doi.org/10.1007/s002080050140},
+}
+
+%%%%
+
+
+%%%%
+
+ at book {deligne77,
+    MRKEY = {MR0463174},
+    AUTHOR = {Deligne, P.},
+     TITLE = {Cohomologie \'etale},
+    SERIES = {Lecture Notes in Mathematics, Vol. 569},
+      NOTE = {S{\'e}minaire de G{\'e}om{\'e}trie Alg{\'e}brique du
+              Bois-Marie SGA 4${1{\o}er 2}$,
+              Avec la collaboration de J. F. Boutot, A. Grothendieck, L.
+              Illusie et J. L. Verdier},
+ PUBLISHER = {Springer-Verlag},
+   ADDRESS = {Berlin},
+      YEAR = {1977},
+     PAGES = {iv+312pp},
+   MRCLASS = {14F20},
+  MRNUMBER = {0463174 (57 \#3132},
+MRREVIEWER = {J. S. Milne},
+}
+
+%%%%
+
+ at incollection {delignerapoport73,
+    MRKEY = {MR0337993},
+    AUTHOR = {Deligne, P. and Rapoport, M.},
+     TITLE = {Les sch\'emas de modules de courbes elliptiques},
+ BOOKTITLE = {Modular functions of one variable, {II} ({P}roc. {I}nternat.
+              {S}ummer {S}chool, {U}niv. {A}ntwerp, {A}ntwerp, 1972)},
+     PAGES = {143--316. Lecture Notes in Math., Vol. 349},
+ PUBLISHER = {Springer},
+   ADDRESS = {Berlin},
+      YEAR = {1973},
+   MRCLASS = {14K10 (10D05)},
+  MRNUMBER = {0337993 (49 \#2762},
+MRREVIEWER = {T. Oda},
+}
+
+%%%%
+
+ at incollection {diamondim95,
+    MRKEY = {MR1357209},
+    AUTHOR = {Diamond, Fred and Im, John},
+     TITLE = {Modular forms and modular curves},
+ BOOKTITLE = {Seminar on {F}ermat's {L}ast {T}heorem ({T}oronto, {ON},
+              1993--1994)},
+    SERIES = {CMS Conf. Proc.},
+    VOLUME = {17},
+     PAGES = {39--133},
+ PUBLISHER = {Amer. Math. Soc.},
+   ADDRESS = {Providence, RI},
+      YEAR = {1995},
+   MRCLASS = {11F11 (11F25 11G05 11G18)},
+  MRNUMBER = {1357209 (97g:11044},
+}
+
+%%%%
+
+
+%%%%
+
+ at article {flach92,
+    MRKEY = {MR1172693},
+    AUTHOR = {Flach, Matthias},
+     TITLE = {A finiteness theorem for the symmetric square of an elliptic
+              curve},
+   JOURNAL = {Invent. Math.},
+  FJOURNAL = {Inventiones Mathematicae},
+    VOLUME = {109},
+      YEAR = {1992},
+    NUMBER = {2},
+     PAGES = {307--327},
+      ISSN = {0020-9910},
+     CODEN = {INVMBH},
+   MRCLASS = {11G40 (11F80 11G05 19F27)},
+  MRNUMBER = {1172693 (93g:11066},
+MRREVIEWER = {Bas Edixhoven},
+        URL = {http://dx.doi.org/10.1007/BF01232029},
+}
+
+%%%%
+
+
+ at article {huber00,
+    MRKEY = {MR1775312},
+    AUTHOR = {Huber, Annette},
+     TITLE = {Realization of {V}oevodsky's motives},
+   JOURNAL = {J. Algebraic Geom.},
+  FJOURNAL = {Journal of Algebraic Geometry},
+    VOLUME = {9},
+      YEAR = {2000},
+    NUMBER = {4},
+     PAGES = {755--799},
+      ISSN = {1056-3911},
+   MRCLASS = {14F42 (14F30 18E30)},
+  MRNUMBER = {1775312 (2002d:14029},
+MRREVIEWER = {Yuichiro Takeda},
+}
+
+%%%%
+
+ at article {iwahorimatsumoto65,
+    MRKEY = {MR0185016},
+    AUTHOR = {Iwahori, N. and Matsumoto, H.},
+     TITLE = {On some {B}ruhat decomposition and the structure of the
+              {H}ecke rings of {${\germ p}$}-adic {C}hevalley groups},
+   JOURNAL = {Inst. Hautes \'Etudes Sci. Publ. Math.},
+  FJOURNAL = {Institut des Hautes \'Etudes Scientifiques. Publications
+              Math\'ematiques},
+    NUMBER = {25},
+      YEAR = {1965},
+     PAGES = {5--48},
+      ISSN = {0073-8301},
+   MRCLASS = {20.70 (14.50)},
+  MRNUMBER = {0185016 (32 \#2486},
+MRREVIEWER = {Rimhak Ree},
+}
+
+%%%%
+
+ at book {jacquet72,
+    MRKEY = {MR0562503},
+    AUTHOR = {Jacquet, Herv{\'e}},
+     TITLE = {Automorphic forms on {${\rm GL}(2)$}. {P}art {II}},
+    SERIES = {Lecture Notes in Mathematics, Vol. 278},
+ PUBLISHER = {Springer-Verlag},
+   ADDRESS = {Berlin},
+      YEAR = {1972},
+     PAGES = {xiii+142},
+   MRCLASS = {10D15 (22E55)},
+  MRNUMBER = {0562503 (58 \#27778},
+MRREVIEWER = {Stephen Gelbart},
+}
+
+%%%%
+
+ at article {jannsen88,
+    MRKEY = {MR929536},
+    AUTHOR = {Jannsen, Uwe},
+     TITLE = {Continuous \'etale cohomology},
+   JOURNAL = {Math. Ann.},
+  FJOURNAL = {Mathematische Annalen},
+    VOLUME = {280},
+      YEAR = {1988},
+    NUMBER = {2},
+     PAGES = {207--245},
+      ISSN = {0025-5831},
+     CODEN = {MAANA},
+   MRCLASS = {14F20 (11G25)},
+  MRNUMBER = {929536 (89a:14022},
+MRREVIEWER = {Wayne Raskind},
+        URL = {http://dx.doi.org/10.1007/BF01456052},
+}
+
+%%%%
+
+
+%%%%
+
+ at article {kato04,
+    MRKEY = {MR2104361},
+    AUTHOR = {Kato, Kazuya},
+     TITLE = {{$p$}-adic {H}odge theory and values of zeta functions of
+              modular forms},
+      NOTE = {Cohomologies $p$-adiques et applications arithm{\'e}tiques.
+              III},
+   JOURNAL = {Ast\'erisque},
+  FJOURNAL = {Ast\'erisque},
+    NUMBER = {295},
+      YEAR = {2004},
+     PAGES = {ix, 117--290},
+      ISSN = {0303-1179},
+   MRCLASS = {11F85 (11F67 11G40 11R33 11S80 14G10 14G35)},
+  MRNUMBER = {2104361 (2006b:11051},
+MRREVIEWER = {Fabrizio Andreatta},
+}
+
+%%%%
+
+ at book {katok92,
+    MRKEY = {MR1177168},
+    AUTHOR = {Katok, Svetlana},
+     TITLE = {Fuchsian groups},
+    SERIES = {Chicago Lectures in Mathematics},
+ PUBLISHER = {University of Chicago Press},
+   ADDRESS = {Chicago, IL},
+      YEAR = {1992},
+     PAGES = {x+175},
+      ISBN = {0-226-42582-7; 0-226-42583-5},
+   MRCLASS = {20H10 (30F35)},
+  MRNUMBER = {1177168 (93d:20088},
+MRREVIEWER = {I. Kra},
+}
+
+%%%%
+
+ at article {kurihara02,
+    MRKEY = {MR1914621},
+    AUTHOR = {Kurihara, Masato},
+     TITLE = {On the {T}ate {S}hafarevich groups over cyclotomic fields of
+              an elliptic curve with supersingular reduction. {I}},
+   JOURNAL = {Invent. Math.},
+  FJOURNAL = {Inventiones Mathematicae},
+    VOLUME = {149},
+      YEAR = {2002},
+    NUMBER = {1},
+     PAGES = {195--224},
+      ISSN = {0020-9910},
+     CODEN = {INVMBH},
+   MRCLASS = {11G05 (11R23)},
+  MRNUMBER = {1914621 (2003f:11078},
+MRREVIEWER = {Vinayak Vatsal},
+        URL = {http://dx.doi.org/10.1007/s002220100206},
+}
+
+%%%%
+
+ at article {landsburg91,
+    MRKEY = {MR1115990},
+    AUTHOR = {Landsburg, Steven E.},
+     TITLE = {Relative {C}how groups},
+   JOURNAL = {Illinois J. Math.},
+  FJOURNAL = {Illinois Journal of Mathematics},
+    VOLUME = {35},
+      YEAR = {1991},
+    NUMBER = {4},
+     PAGES = {618--641},
+      ISSN = {0019-2082},
+     CODEN = {IJMTAW},
+   MRCLASS = {19E15 (14C15 14C35)},
+  MRNUMBER = {1115990 (92i:19007},
+MRREVIEWER = {Luca Barbieri Viale},
+       URL = {http://projecteuclid.org/euclid.ijm/1255987675},
+}
+
+%%%%
+
+ at book {lang02,
+    MRKEY = {MR1878556},
+    AUTHOR = {Lang, Serge},
+     TITLE = {Algebra},
+    SERIES = {Graduate Texts in Mathematics},
+    VOLUME = {211},
+   EDITION = {third},
+ PUBLISHER = {Springer-Verlag},
+   ADDRESS = {New York},
+      YEAR = {2002},
+     PAGES = {xvi+914},
+      ISBN = {0-387-95385-X},
+   MRCLASS = {00A05 (15-02)},
+  MRNUMBER = {1878556 (2003e:00003},
+       URL = {http://dx.doi.org/10.1007/978-1-4613-0041-0},
+}
+
+%%%%
+
+
+%%%%
+
+ at article {levine04,
+    MRKEY = {MR1740880},
+    AUTHOR = {Levine, Marc},
+     TITLE = {Inverting the motivic {B}ott element},
+   JOURNAL = {$K$-Theory},
+  FJOURNAL = {$K$-Theory. An Interdisciplinary Journal for the Development,
+              Application, and Influence of $K$-Theory in the Mathematical
+              Sciences},
+    VOLUME = {19},
+      YEAR = {2000},
+    NUMBER = {1},
+     PAGES = {1--28},
+      ISSN = {0920-3036},
+     CODEN = {KTHEEO},
+   MRCLASS = {14F42 (14F20 19D45 19E08 19E20)},
+  MRNUMBER = {1740880 (2001k:14048},
+       URL = {http://dx.doi.org/10.1023/A:1007874218371},
+}
+
+%%%%
+
+
+%%%%
+
+ at article {loefflerzerbes10,
+    MRKEY = {MR3065158},
+    AUTHOR = {Loeffler, David and Zerbes, Sarah Livia},
+     TITLE = {Wach modules and critical slope {$p$}-adic {$L$}-functions},
+   JOURNAL = {J. Reine Angew. Math.},
+  FJOURNAL = {Journal f\"ur die Reine und Angewandte Mathematik. [Crelle's
+              Journal]},
+    VOLUME = {679},
+      YEAR = {2013},
+     PAGES = {181--206},
+      ISSN = {0075-4102},
+     CODEN = {JRMAA8},
+   MRCLASS = {11R23 (11F80)},
+  MRNUMBER = {3065158},
+}
+
+%%%%
+
+ at book {mazzavoevodskyweibel06,
+    MRKEY = {MR2242284},
+    AUTHOR = {Mazza, Carlo and Voevodsky, Vladimir and Weibel, Charles},
+     TITLE = {Lecture notes on motivic cohomology},
+    SERIES = {Clay Mathematics Monographs},
+    VOLUME = {2},
+ PUBLISHER = {American Mathematical Society},
+   ADDRESS = {Providence, RI},
+      YEAR = {2006},
+     PAGES = {xiv+216},
+      ISBN = {978-0-8218-3847-1; 0-8218-3847-4},
+   MRCLASS = {14F42 (19E15)},
+  MRNUMBER = {2242284 (2007e:14035},
+MRREVIEWER = {Thomas Geisser},
+}
+
+%%%%
+
+
+%%%%
+
+ at article {momose81,
+    MRKEY = {MR617867},
+    AUTHOR = {Momose, Fumiyuki},
+     TITLE = {On the {$l$}-adic representations attached to modular forms},
+   JOURNAL = {J. Fac. Sci. Univ. Tokyo Sect. IA Math.},
+  FJOURNAL = {Journal of the Faculty of Science. University of Tokyo.
+              Section IA. Mathematics},
+    VOLUME = {28},
+      YEAR = {1981},
+    NUMBER = {1},
+     PAGES = {89--109},
+      ISSN = {0040-8980},
+     CODEN = {JFTMAT},
+   MRCLASS = {10D12},
+  MRNUMBER = {617867 (84a:10025},
+MRREVIEWER = {G. Frey},
+}
+
+%%%%
+
+ at article {nekovar06,
+    MRKEY = {MR2333680},
+    AUTHOR = {Nekov{\'a}{\v{r}}, Jan},
+     TITLE = {Selmer complexes},
+   JOURNAL = {Ast\'erisque},
+  FJOURNAL = {Ast\'erisque},
+    NUMBER = {310},
+      YEAR = {2006},
+     PAGES = {viii+559},
+      ISSN = {0303-1179},
+      ISBN = {978-2-85629-226-6},
+   MRCLASS = {11R23 (11F41 11G40 11R34 22E41)},
+  MRNUMBER = {2333680 (2009c:11176},
+MRREVIEWER = {Laurent N. Berger},
+}
+
+%%%%
+
+ at article {ohta99,
+    MRKEY = {MR1674001},
+    AUTHOR = {Ohta, Masami},
+     TITLE = {Ordinary {$p$}-adic \'etale cohomology groups attached to
+              towers of elliptic modular curves},
+   JOURNAL = {Compositio Math.},
+  FJOURNAL = {Compositio Mathematica},
+    VOLUME = {115},
+      YEAR = {1999},
+    NUMBER = {3},
+     PAGES = {241--301},
+      ISSN = {0010-437X},
+     CODEN = {CMPMAF},
+   MRCLASS = {11F33 (11F67 11G18)},
+  MRNUMBER = {1674001 (2000d:11064},
+MRREVIEWER = {Andrea Mori},
+       URL = {http://dx.doi.org/10.1023/A:1000556212097},
+}
+
+%%%%
+
+
+%%%%
+
+ at article {otsuki09,
+    MRKEY = {MR2541166},
+    AUTHOR = {Otsuki, Rei},
+     TITLE = {Construction of a homomorphism concerning {E}uler systems for
+              an elliptic curve},
+   JOURNAL = {Tokyo J. Math.},
+  FJOURNAL = {Tokyo Journal of Mathematics},
+    VOLUME = {32},
+      YEAR = {2009},
+    NUMBER = {1},
+     PAGES = {253--278},
+      ISSN = {0387-3870},
+   MRCLASS = {11G05 (11G40 11R23)},
+  MRNUMBER = {2541166 (2010k:11093},
+MRREVIEWER = {Ahmet Tekcan},
+              URL = {http://dx.doi.org/10.3836/tjm/1249648421},
+}
+
+%%%%
+
+ at article {perrinriou92,
+    MRKEY = {MR1168369},
+    AUTHOR = {Perrin-Riou, Bernadette},
+     TITLE = {Th\'eorie d'{I}wasawa et hauteurs {$p$}-adiques},
+   JOURNAL = {Invent. Math.},
+  FJOURNAL = {Inventiones Mathematicae},
+    VOLUME = {109},
+      YEAR = {1992},
+    NUMBER = {1},
+     PAGES = {137--185},
+      ISSN = {0020-9910},
+     CODEN = {INVMBH},
+   MRCLASS = {11R23 (11G40 11R42 11S25)},
+  MRNUMBER = {1168369 (93g:11109},
+MRREVIEWER = {Douglas L. Ulmer},
+              URL = {http://dx.doi.org/10.1007/BF01232022},
+}
+
+%%%%
+
+
+%%%%
+
+
+%%%%
+
+ at article {pollackstevens11,
+    MRKEY = {MR2760194},
+    AUTHOR = {Pollack, Robert and Stevens, Glenn},
+     TITLE = {Overconvergent modular symbols and {$p$}-adic {$L$}-functions},
+   JOURNAL = {Ann. Sci. \'Ec. Norm. Sup\'er. (4)},
+  FJOURNAL = {Annales Scientifiques de l'\'Ecole Normale Sup\'erieure.
+              Quatri\`eme S\'erie},
+    VOLUME = {44},
+      YEAR = {2011},
+    NUMBER = {1},
+     PAGES = {1--42},
+      ISSN = {0012-9593},
+   MRCLASS = {11F85 (11F67 11S40)},
+  MRNUMBER = {2760194 (2012m:11074},
+MRREVIEWER = {Jeanine Van Order},
+}
+
+%%%%
+
+
+%%%%
+
+ at incollection {quillen73,
+    MRKEY = {MR0338129},
+    AUTHOR = {Quillen, Daniel},
+     TITLE = {Higher algebraic {$K$}-theory. {I}},
+ BOOKTITLE = {Algebraic {$K$}-theory, {I}: {H}igher {$K$}-theories ({P}roc.
+              {C}onf., {B}attelle {M}emorial {I}nst., {S}eattle, {W}ash.,
+              1972)},
+     PAGES = {85--147. Lecture Notes in Math., Vol. 341},
+ PUBLISHER = {Springer},
+   ADDRESS = {Berlin},
+      YEAR = {1973},
+   MRCLASS = {18F25},
+  MRNUMBER = {0338129 (49 \#2895},
+MRREVIEWER = {Stephen M. Gersten},
+}
+
+%%%%
+
+ at article {ramakrishnan00,
+    MRKEY = {MR1792292},
+    AUTHOR = {Ramakrishnan, Dinakar},
+     TITLE = {Modularity of the {R}ankin-{S}elberg {$L$}-series, and
+              multiplicity one for {${\rm SL}(2)$}},
+   JOURNAL = {Ann. of Math. (2)},
+  FJOURNAL = {Annals of Mathematics. Second Series},
+    VOLUME = {152},
+      YEAR = {2000},
+    NUMBER = {1},
+     PAGES = {45--111},
+      ISSN = {0003-486X},
+     CODEN = {ANMAAH},
+   MRCLASS = {11F70 (11F55 11F66 11F80 11G18 14G10 20G35 22E55)},
+  MRNUMBER = {1792292 (2001g:11077},
+MRREVIEWER = {Solomon Friedberg},
+             URL = {http://dx.doi.org/10.2307/2661379},
+}
+
+%%%%
+
+ at article {ribet85,
+    MRKEY = {MR819838},
+    AUTHOR = {Ribet, Kenneth A.},
+     TITLE = {On {$l$}-adic representations attached to modular forms. {II}},
+   JOURNAL = {Glasgow Math. J.},
+  FJOURNAL = {Glasgow Mathematical Journal},
+    VOLUME = {27},
+      YEAR = {1985},
+     PAGES = {185--194},
+      ISSN = {0017-0895},
+     CODEN = {GLMJAS},
+   MRCLASS = {11F11 (11F33 11G10)},
+  MRNUMBER = {819838 (88a:11041},
+MRREVIEWER = {G. Frey},
+              URL = {http://dx.doi.org/10.1017/S0017089500006170},
+}
+
+%%%%
+
+ at book {rubin00,
+    MRKEY = {MR1749177},
+    AUTHOR = {Rubin, Karl},
+     TITLE = {Euler systems},
+    SERIES = {Annals of Mathematics Studies},
+    VOLUME = {147},
+      NOTE = {Hermann Weyl Lectures. The Institute for Advanced Study},
+ PUBLISHER = {Princeton University Press},
+   ADDRESS = {Princeton, NJ},
+      YEAR = {2000},
+     PAGES = {xii+227},
+      ISBN = {0-691-05075-9; 0-691-05076-7},
+   MRCLASS = {11R23 (11G40 11R34 11R42)},
+  MRNUMBER = {1749177 (2001g:11170},
+MRREVIEWER = {Jan Nekov{\'a}{\v{r}}},
+}
+
+%%%%
+
+
+%%%%
+
+ at article {saitosato10,
+    MRKEY = {MR2804264},
+    AUTHOR = {Saito, Shuji and Sato, Kanetomo},
+     TITLE = {A {$p$}-adic regulator map and finiteness results for
+              arithmetic schemes},
+   JOURNAL = {Doc. Math.},
+  FJOURNAL = {Documenta Mathematica},
+      YEAR = {2010},
+    NUMBER = {Extra volume: Andrei A. Suslin sixtieth birthday},
+     PAGES = {525--594},
+      ISSN = {1431-0635},
+   MRCLASS = {14G40 (11G25 14C15 14C25 19F27)},
+  MRNUMBER = {2804264 (2012g:14044},
+MRREVIEWER = {Damian Roessler},
+}
+
+%%%%
+
+ at incollection {scholl98,
+    MRKEY = {MR1696501},
+    AUTHOR = {Scholl, A. J.},
+     TITLE = {An introduction to {K}ato's {E}uler systems},
+ BOOKTITLE = {Galois representations in arithmetic algebraic geometry
+              ({D}urham, 1996)},
+    SERIES = {London Math. Soc. Lecture Note Ser.},
+    VOLUME = {254},
+     PAGES = {379--460},
+ PUBLISHER = {Cambridge Univ. Press},
+   ADDRESS = {Cambridge},
+      YEAR = {1998},
+   MRCLASS = {11G40 (11G16 11G18 11S25 14F30 19F15 19F27)},
+  MRNUMBER = {1696501 (2000g:11057},
+MRREVIEWER = {Amnon Besser},
+              URL = {http://dx.doi.org/10.1017/CBO9780511662010.011},
+}
+
+%%%%
+
+ at article {shahidi81,
+    MRKEY = {MR610479},
+    AUTHOR = {Shahidi, Freydoon},
+     TITLE = {On certain {$L$}-functions},
+   JOURNAL = {Amer. J. Math.},
+  FJOURNAL = {American Journal of Mathematics},
+    VOLUME = {103},
+      YEAR = {1981},
+    NUMBER = {2},
+     PAGES = {297--355},
+      ISSN = {0002-9327},
+     CODEN = {AJMAAN},
+   MRCLASS = {10D15 (10D40 22E45 22E55)},
+  MRNUMBER = {610479 (82i:10030},
+MRREVIEWER = {Stephen Gelbart},
+             URL = {http://dx.doi.org/10.2307/2374219},
+}
+
+%%%%
+
+ at article {shimura76,
+    MRKEY = {MR0434962},
+    AUTHOR = {Shimura, Goro},
+     TITLE = {The special values of the zeta functions associated with cusp
+              forms},
+   JOURNAL = {Comm. Pure Appl. Math.},
+  FJOURNAL = {Communications on Pure and Applied Mathematics},
+    VOLUME = {29},
+      YEAR = {1976},
+    NUMBER = {6},
+     PAGES = {783--804},
+      ISSN = {0010-3640},
+   MRCLASS = {10D15 (10H10)},
+  MRNUMBER = {0434962 (55 \#7925},
+MRREVIEWER = {K.-B. Gundlach},
+}
+
+%%%%
+
+
+%%%%
+
+ at book {shimura00,
+    MRKEY = {MR1780262},
+    AUTHOR = {Shimura, Goro},
+     TITLE = {Arithmeticity in the theory of automorphic forms},
+    SERIES = {Mathematical Surveys and Monographs},
+    VOLUME = {82},
+ PUBLISHER = {American Mathematical Society},
+   ADDRESS = {Providence, RI},
+      YEAR = {2000},
+     PAGES = {x+302},
+      ISBN = {0-8218-2671-9},
+   MRCLASS = {11F67 (11-02 11F30 11F41 11F55)},
+  MRNUMBER = {1780262 (2001k:11086},
+MRREVIEWER = {Hideshi Takayanagi},
+}
+
+%%%%
+
+ at incollection {swinnertondyer72,
+    MRKEY = {MR0406931},
+    AUTHOR = {Swinnerton-Dyer, H. P. F.},
+     TITLE = {On {$l$}-adic representations and congruences for coefficients
+              of modular forms},
+ BOOKTITLE = {Modular functions of one variable, {III} ({P}roc. {I}nternat.
+              {S}ummer {S}chool, {U}niv. {A}ntwerp, 1972)},
+     PAGES = {1--55. Lecture Notes in Math., Vol. 350},
+ PUBLISHER = {Springer},
+   ADDRESS = {Berlin},
+      YEAR = {1973},
+   MRCLASS = {10D05},
+  MRNUMBER = {0406931 (53 \#10717a},
+MRREVIEWER = {K.-B. Gundlach},
+}
+
+%%%%
+
+ at article {voevodsky02,
+    MRKEY = {MR1883180},
+    AUTHOR = {Voevodsky, Vladimir},
+     TITLE = {Motivic cohomology groups are isomorphic to higher {C}how
+              groups in any characteristic},
+   JOURNAL = {Int. Math. Res. Not.},
+  FJOURNAL = {International Mathematics Research Notices},
+      YEAR = {2002},
+    NUMBER = {7},
+     PAGES = {351--355},
+      ISSN = {1073-7928},
+   MRCLASS = {14F42 (14C25 19E15)},
+  MRNUMBER = {1883180 (2003c:14021},
+MRREVIEWER = {Thomas Geisser},
+              URL = {http://dx.doi.org/10.1155/S107379280210403X},
+}
+
+%%%%
+
+


Property changes on: trunk/Master/texmf-dist/doc/support/crossrefware/citations.bib
___________________________________________________________________
Added: svn:eol-style
## -0,0 +1 ##
+native
\ No newline at end of property
Modified: trunk/Master/texmf-dist/doc/support/crossrefware/crossrefware.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/scripts/crossrefware/bbl2bib.pl
===================================================================
--- trunk/Master/texmf-dist/scripts/crossrefware/bbl2bib.pl	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/scripts/crossrefware/bbl2bib.pl	2017-11-19 22:17:35 UTC (rev 45853)
@@ -8,13 +8,15 @@
 
 =head1 SYNOPSIS
 
-bbl2bib.pl [B<-o> I<output>] I<file>
+bbl2bib.pl [-d] [B<-o> I<output>] I<file>
 
 =head1 OPTIONS
 
 =over 4
 
+=item [-d]
 
+Send debugging output to stdout
 
 =item B<-o> I<output>
 
@@ -98,10 +100,13 @@
 use Getopt::Std;
 use URI::Escape;
 use LWP::Simple;
+# Sometimes AMS forgets to update certificates
+$ENV{PERL_LWP_SSL_VERIFY_HOSTNAME}=0;
 
+
 my $USAGE="USAGE: $0 [-o output] file\n";
 my $VERSION = <<END;
-bbl2bib v2.1a
+bbl2bib v2.2
 This is free software.  You may redistribute copies of it under the
 terms of the GNU General Public License
 http://www.gnu.org/licenses/gpl.html.  There is NO WARRANTY, to the
@@ -109,7 +114,7 @@
 $USAGE
 END
 our %opts;
-getopts('c:o:s:hV',\%opts) or die $USAGE;
+getopts('do:hV',\%opts) or die $USAGE;
 
 if ($opts{h} || $opts{V}){
     print $VERSION;
@@ -130,6 +135,10 @@
     $outputfile = $opts{o};
 }
 
+my $debug=0;
+if ($opts{d}) {
+    $debug=1;
+}
 
 
 my $input= IO::File->new($inputfile) or 
@@ -168,7 +177,15 @@
     my $bibitem = shift;
     my $key = $bibitem->{key};
     my $text=$bibitem->{text};
+
+    if ($debug) {
+	print STDOUT "DEBUG: Processing item $key\n";
+    }
+    
     if (!length($text) || $text =~ /^\s+$/s) {
+	if ($debug) {
+	    print STDOUT "DEBUG: No text found\n";
+	}
 	return;
     }
 
@@ -180,21 +197,33 @@
 
     # Arxiv entry?
     if ($text =~ s/\\arxiv\{([^\}]+)\}\.?//) {
+	if ($debug) {
+	    print STDOUT "DEBUG: Found arXiv number $1\n";
+	}
 	$bibitem->{arxiv}=$1;
     }
 
     # Mr number exists?
     if ($text =~ s/\\mr\{([^\}]+)\}\.?//) {
+	if ($debug) {
+	    print STDOUT "DEBUG: Found mr number $1\n";
+	}
 	$bibitem->{mr}=$1;
     }
 
     # zbl  number exists?
     if ($text =~ s/\\zbl\{([^\}]+)\}\.?//) {
+	if ($debug) {
+	    print STDOUT "DEBUG: Found zbl number $1\n";
+	}
 	$bibitem->{zbl}=$1;
     }
 
     # doi  number exists?
     if ($text =~ s/\\doi\{([^\}]+)\}\.?//) {
+	if ($debug) {
+	    print STDOUT "DEBUG: Found doi $1\n";
+	}
 	$bibitem->{doi}=$1;
     }
 
@@ -208,8 +237,14 @@
     my $bibitem = shift;
     my $mirror = "http://www.ams.org/mathscinet-mref";
     my $string=uri_escape_utf8($bibitem->{text});
+    if ($debug) {
+	print STDOUT "Sending $mirror?ref=$string".'&'."dataType=bibtex\n"
+    }
     my $response = $userAgent->get("$mirror?ref=$string&dataType=bibtex") ->
 	decoded_content();
+    if ($debug) {
+	print STDOUT "DEBUG: Response $response\n";
+    }
     if ($response =~ /<pre>(.*)<\/pre>/s) {
 	my $bib= $1;
 	my $fh = new FileHandle;

Modified: trunk/Master/texmf-dist/scripts/crossrefware/bibdoiadd.pl
===================================================================
--- trunk/Master/texmf-dist/scripts/crossrefware/bibdoiadd.pl	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/scripts/crossrefware/bibdoiadd.pl	2017-11-19 22:17:35 UTC (rev 45853)
@@ -104,10 +104,12 @@
 use Getopt::Std;
 use URI::Escape;
 use LWP::Simple;
+# Sometimes AMS forgets to update certificates
+$ENV{PERL_LWP_SSL_VERIFY_HOSTNAME}=0;
 
 my $USAGE="USAGE: $0 [-c config] [-e 1|0] [-f] [-o output] file\n";
 my $VERSION = <<END;
-bibdoiadd v2.1
+bibdoiadd v2.2
 This is free software.  You may redistribute copies of it under the
 terms of the GNU General Public License
 http://www.gnu.org/licenses/gpl.html.  There is NO WARRANTY, to the

Modified: trunk/Master/texmf-dist/scripts/crossrefware/bibmradd.pl
===================================================================
--- trunk/Master/texmf-dist/scripts/crossrefware/bibmradd.pl	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/scripts/crossrefware/bibmradd.pl	2017-11-19 22:17:35 UTC (rev 45853)
@@ -75,10 +75,12 @@
 use URI::Escape;
 use LWP::UserAgent;
 $ENV{PERL_LWP_SSL_VERIFY_HOSTNAME}=0;
+# Sometimes AMS forgets to update certificates
+$ENV{PERL_LWP_SSL_VERIFY_HOSTNAME}=0;
 
 my $USAGE="USAGE: $0  [-d] [-e 1|0] [-f] [-o output] file\n";
 my $VERSION = <<END;
-bibmradd v2.1
+bibmradd v2.2
 This is free software.  You may redistribute copies of it under the
 terms of the GNU General Public License
 http://www.gnu.org/licenses/gpl.html.  There is NO WARRANTY, to the

Modified: trunk/Master/texmf-dist/scripts/crossrefware/bibzbladd.pl
===================================================================
--- trunk/Master/texmf-dist/scripts/crossrefware/bibzbladd.pl	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/scripts/crossrefware/bibzbladd.pl	2017-11-19 22:17:35 UTC (rev 45853)
@@ -78,7 +78,7 @@
 
 my $USAGE="USAGE: $0  [-d] [-e 1|0] [-f] [-o output] file\n";
 my $VERSION = <<END;
-bibzbladd v2.1
+bibzbladd v2.2
 This is free software.  You may redistribute copies of it under the
 terms of the GNU General Public License
 http://www.gnu.org/licenses/gpl.html.  There is NO WARRANTY, to the

Modified: trunk/Master/texmf-dist/scripts/crossrefware/ltx2crossrefxml.pl
===================================================================
--- trunk/Master/texmf-dist/scripts/crossrefware/ltx2crossrefxml.pl	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Master/texmf-dist/scripts/crossrefware/ltx2crossrefxml.pl	2017-11-19 22:17:35 UTC (rev 45853)
@@ -82,7 +82,7 @@
  use File::Spec;
  my $USAGE="USAGE: $0 [-c config] [-o output] file1 file2 ...\n";
 my $VERSION = <<END;
-ltx2crossrefxml v2.0
+ltx2crossrefxml v2.2
 This is free software.  You may redistribute copies of it under the
 terms of the GNU General Public License
 http://www.gnu.org/licenses/gpl.html.  There is NO WARRANTY, to the



More information about the tex-live-commits mailing list
--- trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl	2017-11-19 22:17:06 UTC (rev 45852)
+++ trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl	2017-11-19 22:17:35 UTC (rev 45853)
@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# $Id: tlmgr.pl 45815 2017-11-15 03:45:40Z preining $
+# $Id: tlmgr.pl 45838 2017-11-17 02:13:42Z preining $
 #
 # Copyright 2008-2017 Norbert Preining
 # This file is licensed under the GNU General Public License version 2
@@ -6,9 +6,10 @@
 # or any later version.
 #
 
-my $svnrev = '$Revision: 45815 $';
-my $datrev = '$Date: 2017-11-15 04:45:40 +0100 (Wed, 15 Nov 2017) $';
+my $svnrev = '$Revision: 45838 $';
+my $datrev = '$Date: 2017-11-17 03:13:42 +0100 (Fri, 17 Nov 2017) $';
 my $tlmgrrevision;
+my $tlmgrversion;
 my $prg;
 if ($svnrev =~ m/: ([0-9]+) /) {
   $tlmgrrevision = $1;
@@ -17,7 +18,7 @@
 }
 $datrev =~ s/^.*Date: //;
 $datrev =~ s/ \(.*$//;
-$tlmgrrevision .= " ($datrev)";
+$tlmgrversion = "$tlmgrrevision ($datrev)";
 
 our $Master;
 our $ismain;
@@ -522,7 +523,7 @@
       } else {
         # give a short message about usage
         print "
-tlmgr revision $tlmgrrevision
+tlmgr revision $tlmgrversion
 usage: tlmgr  OPTION...  ACTION  ARGUMENT...
 where ACTION is one of:\n";
         for my $k (sort keys %action_specification) {
@@ -541,7 +542,7 @@
 
   # --machine-readable is only supported by update.
   if ($::machinereadable && 
-    $action ne "update" && $action ne "install" && $action ne "option" && $action ne "shell") {
+    $action ne "update" && $action ne "install" && $action ne "option" && $action ne "shell" && $action ne "remove") {
     tlwarn("$prg: --machine-readable output not supported for $action\n");
   }
 
@@ -666,29 +667,45 @@
 sub give_version {
   if (!defined($::version_string)) {
     $::version_string = "";
-    $::version_string .= "tlmgr revision $tlmgrrevision\n";
+    $::mrversion = "";
+    $::version_string .= "tlmgr revision $tlmgrversion\n";
+    $::mrversion .= "revision $tlmgrrevision\n";
     $::version_string .= "tlmgr using installation: $Master\n";
+    $::mrversion .= "installation $Master\n";
     if (open (REL_TL, "$Master/release-texlive.txt")) {
-      # print first and last lines, which have the TL version info.
-      my @rel_tl = <REL_TL>;
-      $::version_string .= $rel_tl[0];
-      $::version_string .= $rel_tl[$#rel_tl];
+      # print first, which has the TL version info.
+      my $rel_tl = <REL_TL>;
+      $::version_string .= $rel_tl;
+      # for machine readable we only want the last word which is the version
+      my @foo = split(' ', $rel_tl);
+      $::mrversion .= "tlversion $foo[$#foo]\n";
       close (REL_TL);
     }
+    #
+    # add the list of revisions
+    if ($::opt_verbosity > 0) {
+      $::version_string .= "Revisions of TeXLive:: modules:";
+      $::version_string .= "\nTLConfig: " . TeXLive::TLConfig->module_revision();
+      $::version_string .= "\nTLUtils:  " . TeXLive::TLUtils->module_revision();
+      $::version_string .= "\nTLPOBJ:   " . TeXLive::TLPOBJ->module_revision();
+      $::version_string .= "\nTLPDB:    " . TeXLive::TLPDB->module_revision();
+      $::version_string .= "\nTLPaper:  " . TeXLive::TLPaper->module_revision();
+      $::version_string .= "\nTLWinGoo: " . TeXLive::TLWinGoo->module_revision();
+      $::version_string .= "\n";
+    }
+    $::mrversion      .= "TLConfig "   . TeXLive::TLConfig->module_revision();
+    $::mrversion      .= "\nTLUtils "  . TeXLive::TLUtils->module_revision();
+    $::mrversion      .= "\nTLPOBJ "   . TeXLive::TLPOBJ->module_revision();
+    $::mrversion      .= "\nTLPDB "    . TeXLive::TLPDB->module_revision();
+    $::mrversion      .= "\nTLPaper "  . TeXLive::TLPaper->module_revision();
+    $::mrversion      .= "\nTLWinGoo " . TeXLive::TLWinGoo->module_revision();
+    $::mrversion      .= "\n";
   }
-  #
-  # add the list of revisions
-  if ($::opt_verbosity > 0) {
-    $::version_string .= "Revisions of TeXLive:: modules:";
-    $::version_string .= "\nTLConfig: " . TeXLive::TLConfig->module_revision();
-    $::version_string .= "\nTLUtils:  " . TeXLive::TLUtils->module_revision();
-    $::version_string .= "\nTLPOBJ:   " . TeXLive::TLPOBJ->module_revision();
-    $::version_string .= "\nTLPDB:    " . TeXLive::TLPDB->module_revision();
-    $::version_string .= "\nTLPaper:  " . TeXLive::TLPaper->module_revision();
-    $::version_string .= "\nTLWinGoo: " . TeXLive::TLWinGoo->module_revision();
-    $::version_string .= "\n";
+  if ($::machinereadable) {
+    return $::mrversion;
+  } else {
+    return $::version_string;
   }
-  return $::version_string;
 }
 
 

@@ -1120,6 +1137,20 @@
     }
   }
   @packs = keys %packs;
+
+  my %sizes = %{$localtlpdb->sizes_of_packages(
+    $localtlpdb->option("install_srcfiles"),
+    $localtlpdb->option("install_docfiles"), undef, @packs)};
+  defined($sizes{'__TOTAL__'}) || ($sizes{'__TOTAL__'} = 0);
+  my $totalsize = $sizes{'__TOTAL__'};
+  my $totalnr = $#packs;
+  my $currnr = 1;
+  my $starttime = time();
+  my $donesize = 0;
+  
+  print "total-bytes\t$sizes{'__TOTAL__'}\n" if $::machinereadable;
+  print "end-of-header\n" if $::machinereadable;
+
   foreach my $pkg (sort @packs) {
     my $tlp = $localtlpdb->get_package($pkg);
     next if defined($already_removed{$pkg});
@@ -1127,6 +1158,9 @@
       info("$pkg: package not present, cannot remove\n");
       $ret |= $F_WARNING;
     } else {
+      my ($estrem, $esttot) = TeXLive::TLUtils::time_estimate($totalsize,
+                                                              $donesize, $starttime);
+
       # in the first round we only remove collections, nothing else
       # but removing collections will remove all dependencies, too
       # save the information of which packages have already been removed
@@ -1133,11 +1167,18 @@
       # into %already_removed.
       if ($tlp->category eq "Collection") {
         my $foo = 0;
-        info ("$prg: removing $pkg\n");
+        if ($::machinereadable) {
+          machine_line($pkg, "d", $tlp->revision, "-", $sizes{$pkg}, $estrem, $esttot);
+        } else {
+          # info ("$prg: removing $pkg\n");
+          info("[$currnr/$totalnr, $estrem/$esttot] remove: $pkg\n");
+        }
         if (!$opts{"dry-run"}) {
           $foo = backup_and_remove_package($pkg, $autobackup);
           logpackage("remove: $pkg");
         }
+        $currnr++;
+        $donesize += $sizes{$pkg};
         if ($foo) {
           # removal was successful, so the return is at least 0x0001 mktexlsr
           # remove dependencies, too
@@ -1153,8 +1194,19 @@
     }
   }
   foreach my $pkg (sort @more_removal) {
+    my $tlp = $localtlpdb->get_package($pkg);
     if (!defined($already_removed{$pkg})) {
-      info ("$prg: removing package $pkg\n");
+      my ($estrem, $esttot) = TeXLive::TLUtils::time_estimate($totalsize,
+                                                              $donesize, $starttime);
+      # info ("$prg: removing package $pkg\n");
+      if ($::machinereadable) {
+        machine_line($pkg, "d", $tlp->revision, "-", $sizes{$pkg}, $estrem, $esttot);
+      } else {
+        # info ("$prg: removing $pkg\n");
+        info("[$currnr/$totalnr, $estrem/$esttot] remove: $pkg\n");
+      }
+      $currnr++;
+      $donesize += $sizes{$pkg};
       if (!$opts{"dry-run"}) {
         if (backup_and_remove_package($pkg, $autobackup)) {
           # removal was successful
@@ -1164,6 +1216,7 @@
       }
     }
   }
+  print "end-of-updates\n" if $::machinereadable;
   if ($opts{"dry-run"}) {
     # stop here, don't do any postinstall actions
     return ($ret | $F_NOPOSTACTION);
@@ -1171,9 +1224,11 @@
     $localtlpdb->save;
     my @foo = sort keys %already_removed;
     if (@foo) {
-      info("$prg: ultimately removed these packages: @foo\n");
+      info("$prg: ultimately removed these packages: @foo\n")
+        if (!$::machinereadable);
     } else {
-      info("$prg: no packages removed.\n");
+      info("$prg: no packages removed.\n")
+        if (!$::machinereadable);
     }
   }
   return ($ret);
@@ -6194,7 +6249,7 @@
     } elsif ($cmd eq "help") {
       print "Please see tlmgr help or http://tug.org/texlive/tlmgr.html.\n";
     } elsif ($cmd eq "version") {
-      print give_version(), "\n";
+      print give_version();
     } elsif ($cmd =~ m/^(quit|end|bye(bye)?)$/i) {
       return $F_OK;
     } elsif ($cmd eq "setup-location") {
@@ -9259,7 +9314,7 @@
 distribution (L<http://tug.org/texlive>) and both are licensed under the
 GNU General Public License Version 2 or later.
 
-$Id: tlmgr.pl 45815 2017-11-15 03:45:40Z preining $
+$Id: tlmgr.pl 45838 2017-11-17 02:13:42Z preining $
 =cut
 
 # to remake HTML version: pod2html --cachedir=/tmp tlmgr.pl >/tmp/tlmgr.html

Modified: trunk/Master/texmf-dist/doc/man/man1/bbl2bib.1
===================================================================